Clazz.declarePackage("org.iupac");
Clazz.declareInterface(org.iupac, "InChIStructureProvider");
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
